Module types

Module types 

Structs

AbsolutePathBuf
A path that is guaranteed to be absolute and normalized (though it is not guaranteed to be canonicalized or exist on the filesystem).
AccountLoginCompletedNotification
AccountRateLimitsUpdatedNotification
AccountUpdatedNotification
AdditionalFileSystemPermissions
AdditionalNetworkPermissions
AgentMessageDeltaNotification
AgentPath
AnalyticsConfig
AppBranding
AppInfo
AppListUpdatedNotification
AppMetadata
AppReview
AppScreenshot
AppSummary
ApplyPatchApprovalParams
ApplyPatchApprovalResponse
AppsListParams
AppsListResponse
AttestationGenerateParams
AttestationGenerateResponse
ByteRange
CancelLoginAccountParams
CancelLoginAccountResponse
ChatgptAuthTokensRefreshParams
ChatgptAuthTokensRefreshResponse
ClientInfo
CollabAgentState
CommandExecOutputDeltaNotification
CommandExecParams
CommandExecResizeParams
CommandExecResizeResponse
CommandExecResponse
CommandExecTerminalSize
CommandExecTerminateParams
CommandExecTerminateResponse
CommandExecWriteParams
CommandExecWriteResponse
CommandExecutionOutputDeltaNotification
CommandExecutionRequestApprovalParams
CommandExecutionRequestApprovalResponse
CommandMigration
Config
ConfigBatchWriteParams
ConfigEdit
ConfigLayer
ConfigLayerMetadata
ConfigReadParams
ConfigReadResponse
ConfigRequirements
ConfigRequirementsReadResponse
ConfigValueWriteParams
ConfigWarningNotification
ConfigWriteResponse
ContextCompactedNotification
CreditsSnapshot
DeprecationNoticeNotification
DynamicToolCallParams
DynamicToolCallResponse
ErrorNotification
ExecCommandApprovalParams
ExecCommandApprovalResponse
ExperimentalFeature
ExperimentalFeatureEnablementSetParams
ExperimentalFeatureEnablementSetResponse
ExperimentalFeatureListParams
ExperimentalFeatureListResponse
ExternalAgentConfigDetectParams
ExternalAgentConfigDetectResponse
ExternalAgentConfigImportCompletedNotification
ExternalAgentConfigImportParams
ExternalAgentConfigImportResponse
ExternalAgentConfigMigrationItem
FeedbackUploadParams
FeedbackUploadResponse
FileChangeOutputDeltaNotification
FileChangePatchUpdatedNotification
FileChangeRequestApprovalParams
FileChangeRequestApprovalResponse
FileSystemSandboxEntry
FileUpdateChange
FsChangedNotification
FsCopyParams
FsCopyResponse
FsCreateDirectoryParams
FsCreateDirectoryResponse
FsGetMetadataParams
FsGetMetadataResponse
FsReadDirectoryEntry
FsReadDirectoryParams
FsReadDirectoryResponse
FsReadFileParams
FsReadFileResponse
FsRemoveParams
FsRemoveResponse
FsUnwatchParams
FsUnwatchResponse
FsWatchParams
FsWatchResponse
FsWriteFileParams
FsWriteFileResponse
FuzzyFileSearchParams
FuzzyFileSearchResponse
FuzzyFileSearchResult
FuzzyFileSearchSessionCompletedNotification
FuzzyFileSearchSessionUpdatedNotification
GetAccountParams
GetAccountRateLimitsResponse
GetAccountResponse
GitInfo
GrantedPermissionProfile
GuardianApprovalReview
GuardianWarningNotification
HookCompletedNotification
HookErrorInfo
HookMetadata
HookMigration
HookOutputEntry
HookPromptFragment
HookRunSummary
HookStartedNotification
HooksListEntry
HooksListParams
HooksListResponse
InitializeCapabilities
InitializeParams
InitializeResponse
ItemCompletedNotification
ItemGuardianApprovalReviewCompletedNotification
ItemGuardianApprovalReviewStartedNotification
ItemStartedNotification
JSONRPCResponse
ListMcpServerStatusParams
ListMcpServerStatusResponse
LogoutAccountResponse
MarketplaceAddParams
MarketplaceAddResponse
MarketplaceInterface
MarketplaceLoadErrorInfo
MarketplaceRemoveParams
MarketplaceRemoveResponse
MarketplaceUpgradeErrorInfo
MarketplaceUpgradeParams
MarketplaceUpgradeResponse
McpElicitationBooleanSchema
McpElicitationConstOption
McpElicitationLegacyTitledEnumSchema
McpElicitationNumberSchema
McpElicitationSchema
McpElicitationStringSchema
McpElicitationTitledEnumItems
McpElicitationTitledMultiSelectEnumSchema
McpElicitationTitledSingleSelectEnumSchema
McpElicitationUntitledEnumItems
McpElicitationUntitledMultiSelectEnumSchema
McpElicitationUntitledSingleSelectEnumSchema
McpResourceReadParams
McpResourceReadResponse
McpServerElicitationRequestResponse
McpServerMigration
McpServerOauthLoginCompletedNotification
McpServerOauthLoginParams
McpServerOauthLoginResponse
McpServerRefreshResponse
McpServerStatus
McpServerStatusUpdatedNotification
McpServerToolCallParams
McpServerToolCallResponse
McpToolCallError
McpToolCallProgressNotification
McpToolCallResult
MemoryCitation
MemoryCitationEntry
MigrationDetails
Model
ModelAvailabilityNux
ModelListParams
ModelListResponse
ModelProviderCapabilitiesReadParams
ModelProviderCapabilitiesReadResponse
ModelReroutedNotification
ModelServiceTier
ModelUpgradeInfo
ModelVerificationNotification
NetworkApprovalContext
NetworkPolicyAmendment
OverriddenMetadata
PermissionsRequestApprovalParams
PermissionsRequestApprovalResponse
PlanDeltaNotification
PluginDetail
PluginHookSummary
PluginInstallParams
PluginInstallResponse
PluginInterface
PluginListParams
PluginListResponse
PluginMarketplaceEntry
PluginReadParams
PluginReadResponse
PluginShareCheckoutParams
PluginShareCheckoutResponse
PluginShareContext
PluginShareDeleteParams
PluginShareDeleteResponse
PluginShareListItem
PluginShareListParams
PluginShareListResponse
PluginSharePrincipal
PluginShareSaveParams
PluginShareSaveResponse
PluginShareTarget
PluginShareUpdateTargetsParams
PluginShareUpdateTargetsResponse
PluginSkillReadParams
PluginSkillReadResponse
PluginSummary
PluginUninstallParams
PluginUninstallResponse
PluginsMigration
ProcessExitedNotification
ProcessOutputDeltaNotification
ProfileV2
RateLimitSnapshot
RateLimitWindow
ReasoningEffortOption
ReasoningSummaryPartAddedNotification
ReasoningSummaryTextDeltaNotification
ReasoningTextDeltaNotification
RemoteControlStatusChangedNotification
RequestPermissionProfile
Resource
ResourceTemplate
ReviewStartParams
ReviewStartResponse
SandboxWorkspaceWrite
SendAddCreditsNudgeEmailParams
SendAddCreditsNudgeEmailResponse
ServerRequestResolvedNotification
SessionMigration
SkillDependencies
SkillErrorInfo
SkillInterface
SkillMetadata
SkillSummary
SkillToolDependency
SkillsChangedNotification
SkillsConfigWriteParams
SkillsConfigWriteResponse
SkillsListEntry
SkillsListParams
SkillsListResponse
SubagentMigration
TerminalInteractionNotification
TextElement
TextPosition
TextRange
Thread
ThreadApproveGuardianDeniedActionParams
ThreadApproveGuardianDeniedActionResponse
ThreadArchiveParams
ThreadArchiveResponse
ThreadArchivedNotification
ThreadClosedNotification
ThreadCompactStartParams
ThreadCompactStartResponse
ThreadForkParams
ThreadForkResponse
ThreadGoal
ThreadGoalClearedNotification
ThreadGoalUpdatedNotification
ThreadId
ThreadInjectItemsParams
ThreadInjectItemsResponse
ThreadListParams
ThreadListResponse
ThreadLoadedListParams
ThreadLoadedListResponse
ThreadMetadataGitInfoUpdateParams
ThreadMetadataUpdateParams
ThreadMetadataUpdateResponse
ThreadNameUpdatedNotification
ThreadReadParams
ThreadReadResponse
ThreadRealtimeAudioChunk
ThreadRealtimeClosedNotification
ThreadRealtimeErrorNotification
ThreadRealtimeItemAddedNotification
ThreadRealtimeOutputAudioDeltaNotification
ThreadRealtimeSdpNotification
ThreadRealtimeStartedNotification
ThreadRealtimeTranscriptDeltaNotification
ThreadRealtimeTranscriptDoneNotification
ThreadResumeParams
ThreadResumeResponse
ThreadRollbackParams
ThreadRollbackResponse
ThreadSetNameParams
ThreadSetNameResponse
ThreadShellCommandParams
ThreadShellCommandResponse
ThreadStartParams
ThreadStartResponse
ThreadStartedNotification
ThreadStatusChangedNotification
ThreadTokenUsage
ThreadTokenUsageUpdatedNotification
ThreadUnarchiveParams
ThreadUnarchiveResponse
ThreadUnarchivedNotification
ThreadUnsubscribeParams
ThreadUnsubscribeResponse
TokenUsageBreakdown
Tool
ToolRequestUserInputAnswer
ToolRequestUserInputOption
ToolRequestUserInputParams
ToolRequestUserInputQuestion
ToolRequestUserInputResponse
ToolsV2
Turn
TurnCompletedNotification
TurnDiffUpdatedNotification
TurnError
TurnInterruptParams
TurnInterruptResponse
TurnPlanStep
TurnPlanUpdatedNotification
TurnStartParams
TurnStartResponse
TurnStartedNotification
TurnSteerParams
TurnSteerResponse
WarningNotification
WebSearchLocation
WebSearchToolConfig
WindowsSandboxReadinessResponse
WindowsSandboxSetupCompletedNotification
WindowsSandboxSetupStartParams
WindowsSandboxSetupStartResponse
WindowsWorldWritableWarningNotification

Enums

Account
AddCreditsNudgeCreditType
AddCreditsNudgeEmailStatus
ApprovalsReviewer
AskForApproval
AuthMode
AutoReviewDecisionSource
CancelLoginAccountStatus
ChatgptAuthTokensRefreshReason
CodexErrorInfo
CollabAgentStatus
CollabAgentTool
CollabAgentToolCallStatus
CommandAction
CommandExecOutputStream
CommandExecutionApprovalDecision
CommandExecutionSource
CommandExecutionStatus
ConfigLayerSource
DynamicToolCallOutputContentItem
DynamicToolCallStatus
ExperimentalFeatureStage
ExternalAgentConfigMigrationItemType
FileChange
FileChangeApprovalDecision
FileSystemAccessMode
FileSystemPath
FileSystemSpecialPath
ForcedChatgptWorkspaceIds
ForcedLoginMethod
FuzzyFileSearchMatchType
GuardianApprovalReviewAction
GuardianApprovalReviewStatus
GuardianCommandSource
GuardianRiskLevel
GuardianUserAuthorization
HookEventName
HookExecutionMode
HookHandlerType
HookOutputEntryKind
HookRunStatus
HookScope
HookSource
HookTrustStatus
InputModality
LoginAccountParams
LoginAccountResponse
McpAuthStatus
McpElicitationArrayType
McpElicitationBooleanType
McpElicitationEnumSchema
McpElicitationMultiSelectEnumSchema
McpElicitationNumberType
McpElicitationObjectType
McpElicitationPrimitiveSchema
McpElicitationSingleSelectEnumSchema
McpElicitationStringFormat
McpElicitationStringType
McpServerElicitationAction
McpServerElicitationRequestParams
McpServerStartupState
McpServerStatusDetail
McpToolCallStatus
MergeStrategy
MessagePhase
ModelRerouteReason
ModelVerification
NetworkAccess
NetworkApprovalProtocol
NetworkPolicyRuleAction
NonSteerableTurnKind
ParsedCommand
PatchApplyStatus
PatchChangeKind
PermissionGrantScope
Personality
PlanType
PluginAuthPolicy
PluginAvailability
PluginInstallPolicy
PluginListMarketplaceKind
PluginShareDiscoverability
PluginSharePrincipalRole
PluginSharePrincipalType
PluginShareTargetRole
PluginShareUpdateDiscoverability
PluginSource
ProcessOutputStream
RateLimitReachedType
RealtimeConversationVersion
ReasoningEffort
ReasoningSummary
RemoteControlConnectionStatus
RequestId
ResidencyRequirement
ResourceContent
ReviewDecision
ReviewDelivery
ReviewTarget
SandboxMode
SandboxPolicy
SessionSource
SkillScope
SortDirection
SubAgentSource
ThreadActiveFlag
ThreadGoalStatus
ThreadItem
ThreadListCwdFilter
ThreadSortKey
ThreadSource
ThreadSourceKind
ThreadStartSource
ThreadStatus
ThreadUnsubscribeStatus
TurnItemsView
TurnPlanStepStatus
TurnStatus
UserInput
Verbosity
WebSearchAction
WebSearchContextSize
WebSearchMode
WindowsSandboxReadiness
WindowsSandboxSetupMode
WriteStatus