pub struct AbsolutePathBuf(pub String);Expand description
A path that is guaranteed to be absolute and normalized (though it is not guaranteed to be canonicalized or exist on the filesystem).
IMPORTANT: When deserializing an AbsolutePathBuf, a base path must be set using [AbsolutePathBufGuard::new]. If no base path is set, the deserialization will fail unless the path being deserialized is already absolute.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for AbsolutePathBuf
impl Clone for AbsolutePathBuf
Sourcefn clone(&self) -> AbsolutePathBuf
fn clone(&self) -> AbsolutePathBuf
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbsolutePathBuf
impl Debug for AbsolutePathBuf
Sourceimpl Default for AbsolutePathBuf
impl Default for AbsolutePathBuf
Sourcefn default() -> AbsolutePathBuf
fn default() -> AbsolutePathBuf
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AbsolutePathBuf
impl<'de> Deserialize<'de> for AbsolutePathBuf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AbsolutePathBuf
impl Hash for AbsolutePathBuf
Sourceimpl PartialEq for AbsolutePathBuf
impl PartialEq for AbsolutePathBuf
Sourcefn eq(&self, other: &AbsolutePathBuf) -> bool
fn eq(&self, other: &AbsolutePathBuf) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AbsolutePathBuf
impl Serialize for AbsolutePathBuf
impl Eq for AbsolutePathBuf
impl StructuralPartialEq for AbsolutePathBuf