pub struct UserMessageItem {
pub id: String,
pub content: Vec<UserMessageContent>,
}Expand description
A user message item — the prompt the user sent for the current turn.
Emitted by the app-server as the first item in a turn. The exec JSONL protocol does not typically emit this item kind.
Fields
id: Stringcontent: Vec<UserMessageContent>Trait Implementations
Sourceimpl Clone for UserMessageItem
impl Clone for UserMessageItem
Sourcefn clone(&self) -> UserMessageItem
fn clone(&self) -> UserMessageItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserMessageItem
impl Debug for UserMessageItem
Sourceimpl<'de> Deserialize<'de> for UserMessageItem
impl<'de> Deserialize<'de> for UserMessageItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more